Wardy's Unique Beer Check-ins on Untappd
Author: The Untappd Team
Description: Untappd is a new mobile web app that allows you to socially share the brew you're currently enjoying, as well as where you're enjoying it, with your friends!
Keywords: Untappd is a new mobile web app that allows you to socially share the brew you're currently enjoying, as well as where you're enjoying it, with your friends!

### Beer History

Noblesse Oblige

Kicks Brewing

IPA - American

Their Rating (3.9)

Global Rating (4.07)

7.1% ABV

55 IBU

First: Sat, 01 Mar 2025 17:28:53 +1100

Recent: Sat, 01 Mar 2025 17:28:53 +1100

Total: 1

Hyper 8

Ocean Reach Brewing

IPA - American

Their Rating (4.1)

Global Rating (3.85)

7% ABV

N/A IBU

First: Sat, 01 Mar 2025 14:57:04 +1100

Recent: Sat, 01 Mar 2025 14:57:04 +1100

Total: 1

Shredalotl

Ocean Reach Brewing

IPA - American

Their Rating (4)

Global Rating (3.69)

5.8% ABV

N/A IBU

First: Sat, 01 Mar 2025 14:19:58 +1100

Recent: Sat, 01 Mar 2025 14:19:58 +1100

Total: 1

Aztec Fuzz

Ocean Reach Brewing

IPA - New England / Hazy

Their Rating (4.1)

Global Rating (3.82)

6% ABV

N/A IBU

First: Sat, 01 Mar 2025 14:01:10 +1100

Recent: Sat, 01 Mar 2025 14:01:10 +1100

Total: 1

Frank Moses

Ocean Reach Brewing

IPA - Rye

Their Rating (3.7)

Global Rating (3.79)

6.3% ABV

43 IBU

First: Sat, 01 Mar 2025 13:51:31 +1100

Recent: Sat, 01 Mar 2025 13:51:31 +1100

Total: 1

Czech Czech 1, 2

Ocean Reach Brewing

Lager - Tmavé (Czech Dark)

Their Rating (3.9)

Global Rating (3.72)

5.5% ABV

N/A IBU

First: Sat, 01 Mar 2025 13:41:21 +1100

Recent: Sat, 01 Mar 2025 13:41:21 +1100

Total: 1

Back On Track

Range Brewing

IPA - New England / Hazy

Their Rating (4.1)

Global Rating (4.01)

6.1% ABV

N/A IBU

First: Fri, 28 Feb 2025 17:44:45 +1100

Recent: Fri, 28 Feb 2025 17:44:45 +1100

Total: 1

DAYGO

One Drop Brewing Co

IPA - American

Their Rating (3.8)

Global Rating (3.85)

6.3% ABV

N/A IBU

First: Thu, 27 Feb 2025 20:14:10 +1100

Recent: Thu, 27 Feb 2025 20:14:10 +1100

Total: 1

Rough & Tumble

Akasha Brewing Company

IPA - American

Their Rating (4.3)

Global Rating (N/A)

6.8% ABV

N/A IBU

First: Thu, 27 Feb 2025 19:31:22 +1100

Recent: Thu, 27 Feb 2025 19:31:22 +1100

Total: 1

Heart of the Wild - Hoppy Pale

Capital Brewing Co

Pale Ale - Other

Their Rating (3.8)

Global Rating (N/A)

5.2% ABV

22 IBU

First: Thu, 27 Feb 2025 19:00:06 +1100

Recent: Thu, 27 Feb 2025 19:00:06 +1100

Total: 1

Up & Go

Mountain Culture Beer Co.

Pale Ale - New England / Hazy

Their Rating (3.9)

Global Rating (N/A)

4% ABV

N/A IBU

First: Thu, 27 Feb 2025 18:34:53 +1100

Recent: Thu, 27 Feb 2025 18:34:53 +1100

Total: 1

Sage's Smoky Wheat

BentSpoke Brewing Co

Lager - Smoked

Their Rating (3.6)

Global Rating (N/A)

4% ABV

25 IBU

First: Thu, 27 Feb 2025 18:10:01 +1100

Recent: Thu, 27 Feb 2025 18:10:01 +1100

Total: 1

Cross Roads

Akasha Brewing Company

IPA - American

Their Rating (3.9)

Global Rating (3.79)

6.2% ABV

N/A IBU

First: Thu, 27 Feb 2025 17:04:34 +1100

Recent: Thu, 27 Feb 2025 17:04:34 +1100

Total: 1

Double Header

Good Folk Brewing Co

IPA - New England / Hazy

Their Rating (4.3)

Global Rating (3.89)

7.8% ABV

30 IBU

First: Thu, 27 Feb 2025 16:32:54 +1100

Recent: Thu, 27 Feb 2025 16:32:54 +1100

Total: 1

35°C Afternoon Storm Hazy IPA

New England Brewing Co.

IPA - New England / Hazy

Their Rating (4.1)

Global Rating (4.01)

6.8% ABV

50 IBU

First: Thu, 27 Feb 2025 15:31:01 +1100

Recent: Thu, 27 Feb 2025 15:31:01 +1100

Total: 1

Hyper Saturated

Method Brewing

IPA - New England / Hazy

Their Rating (4.2)

Global Rating (4.38)

7% ABV

N/A IBU

First: Thu, 27 Feb 2025 14:54:56 +1100

Recent: Thu, 27 Feb 2025 14:54:56 +1100

Total: 1

Silicon Valley

Method Brewing

IPA - American

Their Rating (4.2)

Global Rating (4.07)

7% ABV

N/A IBU

First: Thu, 27 Feb 2025 14:23:20 +1100

Recent: Thu, 27 Feb 2025 14:23:20 +1100

Total: 1

Jets Juice

Thirsty Messiah Brewery

IPA - New England / Hazy

Their Rating (3.8)

Global Rating (3.78)

6.2% ABV

N/A IBU

First: Thu, 27 Feb 2025 13:33:05 +1100

Recent: Thu, 27 Feb 2025 13:33:05 +1100

Total: 1

Connor’s Cure

Thirsty Messiah Brewery

Pale Ale - Australian

Their Rating (3.7)

Global Rating (3.49)

4.5% ABV

N/A IBU

First: Thu, 27 Feb 2025 13:12:52 +1100

Recent: Thu, 27 Feb 2025 13:12:52 +1100

Total: 1

Stay Tuned

Lost Palms Brewing Co.

IPA - New England / Hazy

Global Rating (3.79)

7% ABV

N/A IBU

First: Mon, 24 Feb 2025 22:57:56 +1100

Recent: Mon, 24 Feb 2025 22:57:56 +1100

Total: 1

Another IPA

4 Pines Brewing Company

IPA - American

Their Rating (3.5)

Global Rating (N/A)

6.7% ABV

56 IBU

First: Sun, 23 Feb 2025 17:04:31 +1100

Recent: Sun, 23 Feb 2025 17:04:31 +1100

Total: 1

Mountain XPA

Dad & Dave's Brewing

Pale Ale - XPA (Extra Pale)

Their Rating (3.6)

Global Rating (N/A)

4.4% ABV

N/A IBU

First: Sun, 23 Feb 2025 15:43:56 +1100

Recent: Sun, 23 Feb 2025 15:43:56 +1100

Total: 1

Yuzu Sour

Dad & Dave's Brewing

Sour - Fruited Berliner Weisse

Their Rating (4)

Global Rating (3.71)

6% ABV

10 IBU

First: Sun, 23 Feb 2025 15:17:10 +1100

Recent: Sun, 23 Feb 2025 15:17:10 +1100

Total: 1

Jack of All Haze

Mountain Culture Beer Co.

Pale Ale - New England / Hazy

Their Rating (3.7)

Global Rating (N/A)

3.8% ABV

N/A IBU

First: Sat, 22 Feb 2025 23:17:24 +1100

Recent: Sat, 22 Feb 2025 23:17:24 +1100

Total: 1

Walk of Fame West Coast Pale Ale

Akasha Brewing Company

Pale Ale - Other

Their Rating (3.7)

Global Rating (3.68)

5.3% ABV

N/A IBU

First: Sat, 22 Feb 2025 22:23:00 +1100

Recent: Sat, 22 Feb 2025 22:23:00 +1100

Total: 1

Show More